[git] GpgOL - branch, master, updated. gpgol-2.1.1-6-g8539f6b

by Andre Heinecke cvs at cvs.gnupg.org
Fri May 11 09:07:43 CEST 2018


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GnuPG extension for MS Outlook".

The branch, master has been updated
       via  8539f6bc595d5539d2a528fe5349c8749549ac68 (commit)
      from  aed389f9ce639db48dcfc84cb495a2b180496207 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 8539f6bc595d5539d2a528fe5349c8749549ac68
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Fri May 11 09:05:09 2018 +0200

    Stop prasing on non whitepspace before PGP Message
    
    * src/mapihelp.cpp (get_msgcls_from_pgp_lines): Again break
    on non whitespace before message marker.
    
    --
    The problem here is that for inline messages a full quote in
    the response could cause GpgOL to use the full quote as the
    message instead of the reply. Outlook itself formats
    its quotes in a way that would cause this.
    
    While this might break again MTA's which insert stuff above
    a Message we have to do this.
    
    GnuPG-Bug-Id: T3964

diff --git a/src/mapihelp.cpp b/src/mapihelp.cpp
index 16e45eb..f5ec627 100644
--- a/src/mapihelp.cpp
+++ b/src/mapihelp.cpp
@@ -744,14 +744,19 @@ get_msgcls_from_pgp_lines (LPMESSAGE message, bool *r_nobody = nullptr)
             msgcls = xstrdup ("IPM.Note.GpgOL.PGPMessage");
           break;
         }
-
-#if 0
-      This might be too strict for some broken implementations. Lets
-      look anywhere in the first 1k.
       else if (!trailing_ws_p (p))
-        break;  /* Text before the PGP message - don't take this as a
-                   proper message.  */
-#endif
+        {
+          /* We have text before the message. In that case we need
+             to break because some bad MUA's like Outlook do not insert
+             quote characters before a replied to message. In that case
+             the reply to an inline Mail from an Outlook without GpgOL
+             enabled could cause the behavior that we would detect
+             the original message.
+          */
+          log_debug ("%s:%s: Detected non whitespace %c before a PGP Marker",
+                     SRCNAME, __func__, *p);
+          break;
+        }
     }
 
 

-----------------------------------------------------------------------

Summary of changes:
 src/mapihelp.cpp | 19 ++++++++++++-------
 1 file changed, 12 insertions(+), 7 deletions(-)


hooks/post-receive
-- 
GnuPG extension for MS Outlook
http://git.gnupg.org




More information about the Gnupg-commits mailing list